@@ -4,7 +4,9 @@ use warnings;
 
 package Pod::Weaver::PluginBundle::Author::CSSON;
 
-our $VERSION = '0.1100'; # VERSION
+# ABSTRACT: Weave Pod like CSSON
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1101';
 
 use strict;
 use warnings;
@@ -27,7 +29,7 @@ sub mvp_bundle_config {
             $include_default_github = 1;
         }
         else {
-            warn ('[PW/@Author::CSSON] No github url found');
+            warn ('[PW/@Author: ] No github url found');
         }
     }
 
@@ -63,16 +65,14 @@ sub mvp_bundle_config {
         ['@Author::CSSON/Legal',                 xp('Legal'),     { } ],
 
         ['@Author::CSSON/List', xp('-Transformer'), { transformer => 'List' } ],
+        ['@Author::CSSON/Splint', xp('-Transformer'), { transformer => 'Splint' } ],
     );
 
-
     return @plugins;
 }
 
 1;
 
-# ABSTRACT: Weave Pod like CSSON
-
 __END__
 
 =pod
@@ -85,7 +85,11 @@ Pod::Weaver::PluginBundle::Author::CSSON - Weave Pod like CSSON
 
 =head1 VERSION
 
-Version 0.1100, released 2015-01-07.
+Version 0.1101, released 2016-02-18.
+
+=head1 STATUS
+
+Deprecated. See L<Dist::Iller::Config::Author::CSSON> instead.
 
 =head1 SOURCE
 
@@ -101,7 +105,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
